@@ -13,6 +13,8 @@
 
 use idna;
 
+pub use ::cookie::{Cookie as RawCookie, ParseError as RawCookieParseError};
+
 mod cookie;
 pub use crate::cookie::Error as CookieError;
 pub use crate::cookie::{Cookie, CookieResult};
@@ -23,7 +25,7 @@ pub use crate::cookie_expiration::CookieExpiration;
 mod cookie_path;
 pub use crate::cookie_path::CookiePath;
 mod cookie_store;
-pub use crate::cookie_store::CookieStore;
+pub use crate::cookie_store::{CookieStore, StoreAction};
 mod utils;
 
 #[derive(Debug)]
